@@ -22,12 +22,13 @@ class Network3Medusa():
         raw_json=self.output.stdout.decode('utf-8')
         if 'eth_admin_fec_state' in raw_json:
             json_dict = json.loads(raw_json)
-            print(json_dict)
-            for interface in enumerate(json_dict.get()):
+            for interface in enumerate(json_dict):
                 if interface == 0:
-                    self.add_file_to_hedera(interface)
+                    raw_json=interface
+                    self.add_file_to_hedera(raw_json)
                 else:
-                    self.append_file_to_hedera(interface)
+                    raw_json=interface
+                    self.append_file_to_hedera(raw_json)
             print(self.receipt.toString())
 
             query = FileInfoQuery().setFileId(self.fileId)
